using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Windows.Forms;
using Infragistics.Win.UltraWinGrid;
using Infragistics.Win;
using System.Diagnostics;
using Infragistics.Shared;
using System.IO;
using Infragistics.Win.AppStyling;
using Infragistics.Win.UltraWinEditors;
using System.Collections;


namespace MemDataTable_CS
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private DataTable dt1;

        private void Form1_Load(object sender, System.EventArgs e)
        {
            // Set grid's DataSource            
            dt1 = DummyDataCreator.GetData(100);

            dt1.TableName = "Band 0";

            this.ultraGrid1.SetDataBinding(dt1, null);

            this.ultraGrid1.DrawFilter = new ActiveRowBorderDrawFilter();
        }

        private void ultraGrid1_AfterRowActivate(object sender, EventArgs e)
        {
            // Since we are drawing a border around the ActiveRow which extends outside the
            // row, we have to make sure that the entire area outside the row gets invalidated
            // any time the active row changes. 
            // We could make this more efficient by calculating the exact rect, but it's 
            // easier just to invalidate the whole grid. This won't be a problem unless the grid
            // is especially large or complex. 
            //
            UltraGrid grid = (UltraGrid)sender;
            grid.Invalidate();
        }       
    }

    public class ActiveRowBorderDrawFilter : IUIElementDrawFilter
    {
        private int borderThickness = 6;
        private Color borderColor = Color.Red;

        #region IUIElementDrawFilter Members

        bool IUIElementDrawFilter.DrawElement(DrawPhase drawPhase, ref UIElementDrawParams drawParams)
        {

            UIElement rowColRegionIntersectionUIElement = drawParams.Element;

            // Loop through the child elements. 
            foreach (UIElement childElement in rowColRegionIntersectionUIElement.ChildElements)
            {
                // Look for RowUIElements. 
                RowUIElement rowElement = childElement as RowUIElement;
                if (rowElement == null)
                    continue;

                // Does this UIElement represent the ActiveRow? 
                UltraGridRow row = rowElement.Row;
                if (row.IsActiveRow)
                {
                    // Start with the Element's rect. 
                    Rectangle rect = rowElement.Rect;

                    // Clip the rect so it doesn't extend outside the RowColRegionIntersectionUIElement.
                    rect.Intersect(rowColRegionIntersectionUIElement.RectInsideBorders);

                    // Inflate the rect by half of the border thickness so the entire border is
                    // drawn outside the actual row. This will prevent any controls inside
                    // the row from clipping the border.
                    rect.Inflate(new Size(this.borderThickness / 2, this.borderThickness/2));

                    // Draw the rect. 
                    using (Pen pen = new Pen(this.borderColor, this.borderThickness))
                        drawParams.Graphics.DrawRectangle(pen, rect);
                }
            }

            // Return false to indicate that the grid should just go ahead and do any normal
            // processing. 
            return false;
        }

        DrawPhase IUIElementDrawFilter.GetPhasesToFilter(ref UIElementDrawParams drawParams)
        {
            // Trap for the element that contains the Rows. 
            if (drawParams.Element is RowColRegionIntersectionUIElement)
            {
                // Handle the phase after this element is drawn.
                return DrawPhase.AfterDrawElement;
            }

            return DrawPhase.None;
        }

        #endregion
    }

}